[Libreoffice-commits] core.git: include/cppuhelper

Noel Grandin noel at peralex.com
Wed Oct 21 04:15:38 PDT 2015


 include/cppuhelper/weak.hxx |    6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

New commits:
commit 44440680708d294a65e02c956c1e8423cca7f7d6
Author: Noel Grandin <noel at peralex.com>
Date:   Wed Oct 21 13:14:53 2015 +0200

    attempt to placate Doxygen
    
    Change-Id: Ia29a9aa59c234a92366113e176931bc286ec8abb

diff --git a/include/cppuhelper/weak.hxx b/include/cppuhelper/weak.hxx
index c3e8be5..4f06c3a 100644
--- a/include/cppuhelper/weak.hxx
+++ b/include/cppuhelper/weak.hxx
@@ -123,8 +123,8 @@ public:
     inline OWeakObject & SAL_CALL operator = ( const OWeakObject &)
         { return *this; }
 
-    /** Basic queryInterface() implementation supporting \css::uno::XWeak and
-        \css::uno::XInterface.
+    /** Basic queryInterface() implementation supporting \com::sun::star::uno::XWeak and
+        \com::sun::star::uno::XInterface.
 
         @param rType demanded type
         @return demanded type or empty any
@@ -143,7 +143,7 @@ public:
 
     /** XWeak::queryAdapter() implementation
 
-        @return a \css::uno::XAdapter reference
+        @return a \com::sun::star::uno::XAdapter reference
     */
     virtual css::uno::Reference< css::uno::XAdapter > SAL_CALL queryAdapter()
         throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE;


More information about the Libreoffice-commits mailing list